The serial number of traits in each cluster group.
cluster.matrix
The new EQF matrix after the clustering process.
permu.matrix.cluster
The permutation result of the clustering
method, which has been sorted by order.
permu.matrix.Q
The permutation result of the Q method, which has
been sorted by order.
EQF.threshold
The EQF threshold is calculated from the
permutation process.
Arguments
LOD.QTLdetect.result
list. The data list of the output from
LOD.QTLdetect().
ptime
integer. The permutation times.
alpha
numeric. The type 1 error rate of detecting the hotspot.
Q
logical. When set to TRUE, the function will additionally carry
out the permutation of the Q method as the control group, which will be
indicated as 'B' in the output.
console
logical. Determines whether the process of the algorithm
will be displayed in the R console or not.
References
Wu, P.-Y., M.-.H. Yang, and C.-H. KAO 2021 A Statistical Framework
for QTL Hotspot Detection. G3: Genes, Genomes, Genetics: jkab056. <doi: 10.1093/g3journal/jkab056>
# load the example dataload(system.file("extdata", "LODexample.RDATA", package = "QTLEMM"))
# run and resultresult <- EQF.permu(LOD.QTLdetect.result, ptime = 50)
result$cluster.number