Learn R Programming

QTLEMM (version 3.0.1)

EQF.plot: EQF plot

Description

Generate an EQF plot based on the result of the permutation process used to detect the QTL hotspot.

Usage

EQF.plot(result, plot.all = TRUE, plot.chr = TRUE, plot.main = TRUE)

Value

One or several EQF plots.

Arguments

result

list. The data list of the output from LOD.QTLdetect(), EQF.permu(), or Qhot.EQF().

plot.all

logical. When set to TRUE, it directs the function to output one figure of the EQF values over the bins.

plot.chr

logical. When set to TRUE, it instructs the function to output the figures of the EQF values over the bins for each chromosome.

plot.main

logical of character. When set to TRUE, it will use the default title on the plot. When set to FALSE, it will be no title on the plot. Users can also use this argument to set their own title.

References

Wu, P.-Y., M.-.H. Yang, and C.-H. KAO 2021 A Statistical Framework for QTL Hotspot Detection. G3: Genes, Genomes, Genetics: jkab056. <doi: 10.1093/g3journal/jkab056>

See Also

LOD.QTLdetect EQF.permu Qhot.EQF

Examples

Run this code
# load the example data
load(system.file("extdata", "LODexample.RDATA", package = "QTLEMM"))

# run and result
EQF.plot(LOD.QTLdetect.result)
EQF.plot(EQF.permu.result)

Run the code above in your browser using DataLab